@@ -2,7 +2,7 @@ import urlparse
 import posixpath
 import urllib
 
-__version__ = '0.1'
+__version__ = '0.2'
 
 
 def querydict_to_querylist(querydict):
@@ -20,14 +20,20 @@ def url_join(base, *args, **querydict):
     Helper function to join an arbitrary number of url segments together.
     """
     scheme, netloc, path, query, fragment = urlparse.urlsplit(base)
-    path = path if len(path) else "/"
-    path = posixpath.join(path, *[('%s' % x) for x in args])
-
-    # update the querydict
+    # parse the querylist
     querylist = urlparse.parse_qsl(query)
+
+    path = path if len(path) else "/"
+    for x in args:
+        bits = x.split("?")
+        if len(bits) == 2:
+            querylist.extend(urlparse.parse_qsl(bits[1]))
+        path = posixpath.join(path, bits[0])
+
+    # update the querylist
     querylist.extend(querydict_to_querylist(querydict))
 
-    # encode the querydict
+    # encode the querylist
     query = urllib.urlencode(querylist)
     
     return urlparse.urlunsplit([scheme, netloc, path, query, fragment])
@@ -49,6 +55,7 @@ class Url(object):
 
     def __repr__(self):
         return "<doze %s>" % (str(self))
-    
+
 def url(base):
     return Url(base)
+
